@@ -255,11 +255,13 @@ class ArrayNameSpace:
             The starting index of the slice.
         length
             The length of the slice.
+        as_array
+            Return the result as a Series of data type :class:`.Array`.
 
         Returns
         -------
         Series
-            Series of data type :class:`Array`.
+            Series of data type :class:`.List` or :class:`.Array` if `as_array=True`.
 
         Examples
         --------
@@ -774,3 +776,60 @@ class ArrayNameSpace:
             [6, null, null]
         ]
         """
+
+    def eval(self, expr: Expr, *, as_list: bool = False) -> Series:
+        """
+        Run any polars expression against the arrays' elements.
+
+        Parameters
+        ----------
+        expr
+            Expression to run. Note that you can select an element with `pl.element()`
+        as_list
+            Collect the resulting data as a list. This allows for expressions which
+            output a variable amount of data.
+
+        Examples
+        --------
+        >>> s = pl.Series("a", [[1, 4], [8, 5], [3, 2]], pl.Array(pl.Int64, 2))
+        >>> s.arr.eval(pl.element().rank())
+        shape: (3,)
+        Series: 'a' [array[f64, 2]]
+        [
+            [1.0, 2.0]
+            [2.0, 1.0]
+            [2.0, 1.0]
+        ]
+        """
+
+    def agg(self, expr: Expr) -> Series:
+        """
+        Run any polars aggregation expression against the arrays' elements.
+
+        Parameters
+        ----------
+        expr
+            Expression to run. Note that you can select an element with `pl.element()`.
+
+        Examples
+        --------
+        >>> s = pl.Series(
+        ...     "a", [[1, None], [42, 13], [None, None]], pl.Array(pl.Int64, 2)
+        ... )
+        >>> s.arr.agg(pl.element().null_count())
+        shape: (3,)
+        Series: 'a' [u32]
+        [
+            1
+            0
+            2
+        ]
+        >>> s.arr.agg(pl.element().drop_nulls())
+        shape: (3,)
+        Series: 'a' [list[i64]]
+        [
+            [1]
+            [42, 13]
+            []
+        ]
+        """
